Learn R Programming

rQSAR (version 1.0.0)

generate_descriptors_from_sdf: Generate Molecular Descriptors from SDF File

Description

This function reads an SDF (Structure Data File) containing molecular structures and calculates molecular descriptors for each molecule.

Usage

generate_descriptors_from_sdf(sdf_file)

Value

A matrix containing molecular descriptors for each molecule in the SDF file.

Arguments

sdf_file

Path to the SDF file.