residual_plots: Function to create residual plots with model type labels
Description
Function to create residual plots with model type labels
Usage
residual_plots(model_results)
Value
A list of ggplot objects representing residual plots
Arguments
- model_results
A list containing model results